@@ -16,7 +16,7 @@
 #endif
 
 #ifndef BUILD_GLES3
-/* #undef BUILD_GLES3 */
+#define BUILD_GLES3
 #endif
 
 // Miscellaneous flags
@@ -60,7 +60,7 @@
 #endif
 
 #ifndef USE_EDITLINE
-/* #undef USE_EDITLINE */
+#define USE_EDITLINE
 #endif
 
 #ifndef USE_ELF
@@ -72,7 +72,7 @@
 #endif
 
 #ifndef USE_FFMPEG
-#define USE_FFMPEG
+/* #undef USE_FFMPEG */
 #endif
 
 #ifndef USE_GDB_STUB
@@ -119,4 +119,10 @@
 #define USE_ZLIB
 #endif
 
+// HAVE flags
+
+#ifndef HAVE_POPCOUNT32
+#define HAVE_POPCOUNT32
+#endif
+
 #endif
